# Generated by Django 2.2.9 on 2020-01-22 06:24

from django.db import migrations, models
import django_dj_plugin.month.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Example',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=20)),
                ('month', django_dj_plugin.month.models.MonthField(help_text='some help...', verbose_name='Month Value')),
            ],
        ),
    ]
